///////////////////////////////////////////////////////////////////////////////
//  ____________
// |   |    _   |
// | S | __|_|__|  WSP High Level API Test
// | P |  /  |  |  ~~~~~~~~~~~~~~~~~~~~~~~
// | Y | /-  |  |  Copyright (C)1996-2003 SpyTech
// | T |  |  \  |
// | E |  | _/  |  Author: Radek Tetik
// | C |  |__|  |  Last changed: 2003 01
// | H |  _||   |
// |___|________|
//
///////////////////////////////////////////////////////////////////////////////

// NOTE:
// This application can be used for testing both 
// the DLL and static version of WSP High Level API.
// If you use it for testing the DLL version, uncomment 
// "#define WSP_DLL_API" line.

#include "stdafx.h"
#define WSP_DLL_API
#include "..\High Level API\wsp.h"

#include <io.h>
#include <sys/types.h>
#include <fcntl.h>

//*****************************************************************************
int main(int argc, char* argv[])
{
	HMOD h;
	CWsp p;
	CWspStatus2 s;

	// Init

	BOOL bThereIsSoundCard = p.Init(CWsp::CUBIC);

	// Load a module

	printf("Loading a module...\n");
	h = p.LoadMod("satell.s3m");

	// This block of code presents an alternative
	// way of loading a module. The module is loaded
	// from the memory which allows to load it e.g. from resources.

	/*{
	int f = _open("satell.s3m", _O_RDONLY);
	BYTE* b = new BYTE[39778];
	_read(f, b, 39778);
	_close(f);
	h = p.LoadMod(b, 39778);
	delete b;
	}*/

	_ASSERT(h);

	// Play!

	printf("Playing for 1 second...\n");
	p.Play(h, true);
	Sleep(1000);
	
	printf("Pausing for 1 second...\n");
	p.Pause();
	Sleep(1000);
	p.Resume();
	printf("Playing. Press any key to quit...\n");

	while (!_kbhit())
	{
		Sleep(100);
		p.GetStatus(s);
		printf("order=%d; row=%d; time=%d\n", s.nCurOrder, s.nCurRow, s.nTimeStamp/1000);
	}

	printf("Fading out the volume and stopping...\n");
	p.FadeOut();
	while (p.IsPlaying()) Sleep(100);
	
	// Deinit

	p.FreeMod(h);
	p.Deinit();

	return 0;
}

