///////////////////////////////////////////////////////////////////////////////
//  ____________
// |   |    _   |
// | S | __|_|__|  WSP High Level API
// | P |  /  |  |  ~~~~~~~~~~~~~~~~~~
// | Y | /-  |  |  Copyright (C)1996-2003 Radek Tetik/SpyTech
// | T |  |  \  |
// | E |  | _/  |  e-mail: info@spytech.cz
// | C |  |__|  |  http://www.spytech.cz
// | H |  _||   |
// |___|________|
//
///////////////////////////////////////////////////////////////////////////////

#pragma once

#ifndef WSP_DLL_API
#define WSP_DLL_API __declspec(dllimport)
#endif

typedef void* HMOD;

//*****************************************************************************
struct CWspStatus2
{	
  int nTempo;					// current tempo
  int nSpeed;					// current speed
  int nNumOrders;			// num of orders in the module
  int nCurOrder;			// current order, one based
  int nCurRow;				// current row, one based
	int nNumRows;				// num of rows in the current pattern
	int	nTimeStamp;			// current output time, in [ms]
};

//*****************************************************************************
class WSP_DLL_API CWsp  
{
public:
	enum	EInterpolation { NONE=0, LINEAR=1, CUBIC=2 };

private:
	class CWspPlayer*	m_ppl;
	class CWspDrv*		m_pDrv;			

public:
	CWsp();
	~CWsp();

	// Call before any other function!
	// Returns TRUE if a sound card was found, otherwise FALSE.
	// NOTE: If no sound card was found, the no_sound driver
	// is used and the player behaves normally as if there is a
	// sound card, i.e. the status can be queried, etc.
	BOOL Init(EInterpolation eInterpolation);

	// Call at the end of your application.
	void Deinit();

	// Loads a module from the specified file
	// to the memory and returns a handle to it.
	// Currently MOD, S3M and XM format is supported.
	// The module type is determined by significant differences among formats.
	HMOD LoadMod(const char* pcszFileName);

	// Loads a module from the given memory chunk.
	// The module type is determined by significant differences among formats.
	HMOD LoadMod(const void* pcData, int nSize);

	// Frees a module handle.
	void FreeMod(HMOD hMod);

	// Plays the module. If bLoopSong is TRUE, the music is looped
	// forever.
	void Play(HMOD hMod, BOOL bLoopSong);

	// Stops the playback immediately.
	void Stop();

	// Stops the playback, but at first it fades out the volume.
	// It's a non-blocking call, it starts the fade out and 
	// returns immediately, the playback is stopped a few 
	// seconds later.
	// NOTE: There is a little delay before the fade out starts
	// because of the buffering.
	void FadeOut();

	// Pauses/resumes the playback.
	void Pause();
	void Resume();

	// Queries the player status.
	BOOL IsPlaying() const;
	BOOL IsPaused() const;

	// Sets the playback volume. nVol=<0,65535>
	void SetVolume(int nVol);

	// Fills the given structure with the current
	// player status.
	// If s.nTimeStamp == -1 then no status is available.
	void GetStatus(CWspStatus2& s);
};

